<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="text"/>
<xsl:param name="MID"/>  
<xsl:param name="SID"/>  
<xsl:param name="SECRET"/>

<xsl:variable name="RESPONSE" select="'Response'"/>
<xsl:variable name="PARAMS" select="'Params'"/>
<xsl:variable name="STRING" select="'string'"/>
<xsl:variable name="STRUCT" select="'struct'"/>
<xsl:variable name="ARRAY" select="'array'"/>

<xsl:include href="errors.xsl"/>

<xsl:template match="/">
 <xsl:apply-templates select="/data/response"/>
 <xsl:apply-templates select="/data/error"/>
 <xsl:apply-templates select="/data/info"/>
</xsl:template>

<xsl:template match="response">

    <xsl:element name="{$RESPONSE}">
        <xsl:attribute name="class">places</xsl:attribute>
        <xsl:attribute name="function">getCheckins</xsl:attribute>
        <xsl:element name="{$PARAMS}">

            <xsl:element name="{$ARRAY}">
                <xsl:variable name="quantity" select="count(checkins/item)"/>

                <xsl:attribute name="name">checkinList</xsl:attribute>

                <xsl:attribute name="count">
					<xsl:value-of select="count(checkins/item)"/>
				</xsl:attribute>

                <xsl:for-each select="checkins/item">
                    <xsl:if test="id">
                        <xsl:element name="{$STRUCT}">
                            <xsl:attribute name="name">checkin</xsl:attribute>
                            <xsl:attribute name="id">
                            	<xsl:value-of select="id"/>
                            </xsl:attribute>

                            <xsl:element name="{$STRING}">
                               <xsl:attribute name="name">uid</xsl:attribute>
                               <xsl:value-of select="uid"/>
                            </xsl:element> 

                            <xsl:if test="uid">
                                <xsl:if test="uid != '0'">
                                    <xsl:variable name="current_uid" select="uid"/>
                                    <xsl:element name="{$STRING}">
                                       <xsl:attribute name="name">uname</xsl:attribute>
                                            <xsl:value-of select="//sender/item[uid=$current_uid]/first_name"/>
                                            <xsl:text> </xsl:text>
                                            <xsl:value-of select="//sender/item[uid=$current_uid]/last_name"/>
                                    </xsl:element>
									<xsl:element name="{$STRING}">
                                       <xsl:attribute name="name">uphoto</xsl:attribute>
                                            <xsl:value-of select="//sender/item[uid=$current_uid]/photo_rec"/>
                                    </xsl:element>
                                </xsl:if>
                            </xsl:if>

                            <xsl:element name="{$STRING}">
                                <xsl:attribute name="name">date</xsl:attribute>
                                <xsl:value-of select="date"/>
                            </xsl:element>
							<xsl:element name="{$STRING}">
                            	<xsl:attribute name="name">latitude</xsl:attribute>
                            	<xsl:value-of select="latitude"/>
                       		</xsl:element>
							<xsl:element name="{$STRING}">
                            	<xsl:attribute name="name">longitude</xsl:attribute>
                            	<xsl:value-of select="longitude"/>
                        	</xsl:element>
                            <xsl:element name="{$STRING}">
                                <xsl:attribute name="name">text</xsl:attribute>
                                <xsl:value-of select="text"/>
                            </xsl:element>
							<xsl:element name="{$STRING}">
                           		<xsl:attribute name="name">place_id</xsl:attribute>
                           		<xsl:value-of select="place_id"/>
                    		</xsl:element>
							<xsl:element name="{$STRING}">
                           		<xsl:attribute name="name">place_title</xsl:attribute>
                           		<xsl:value-of select="place_title"/>
                    		</xsl:element>
							<xsl:element name="{$STRING}">
                           		<xsl:attribute name="name">place_city</xsl:attribute>
                           		<xsl:value-of select="place_city"/>
                    		</xsl:element>
							<xsl:element name="{$STRING}">
                           		<xsl:attribute name="name">place_country</xsl:attribute>
                           		<xsl:value-of select="place_country"/>
                    		</xsl:element>
							<xsl:element name="{$STRING}">
                           		<xsl:attribute name="name">place_address</xsl:attribute>
                           		<xsl:value-of select="place_address"/>
                    		</xsl:element>
							<xsl:element name="{$STRING}">
                           		<xsl:attribute name="name">place_type</xsl:attribute>
                           		<xsl:value-of select="place_type"/>
                    		</xsl:element>
							<xsl:element name="{$STRING}">
                           		<xsl:attribute name="name">place_icon</xsl:attribute>
                           		<xsl:value-of select="place_icon"/>
                    		</xsl:element>
								
                        </xsl:element>
					</xsl:if>
                </xsl:for-each>

            </xsl:element> 

        </xsl:element> 
    </xsl:element> 
</xsl:template>

</xsl:stylesheet>
